package test;

import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import org.apache.ibatis.io.Resources;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.apache.ibatis.session.SqlSessionFactoryBuilder;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import com.demo.mybatis.MyBatisRepository;
import com.demo.mybatis.Repository;

public class TestRepository {

	@Before
	public void before() {
		try {
			String resource = "mybatis/mybatis-config.xml";
			InputStream inputStream = Resources.getResourceAsStream(resource);
			SqlSessionFactory sqlSessionFactory = new SqlSessionFactoryBuilder().build(inputStream);
			logger.debug("xml sqlSessionFactory:{}", sqlSessionFactory);

			sqlSession = sqlSessionFactory.openSession();

			logger.debug("sqlSession:{}", sqlSession);

			String nameSpace = "TestMapper";
			String tableName = "user";
			repository = new MyBatisRepository(sqlSession, nameSpace, tableName);
		} catch (IOException e) {
			logger.debug("error:{}", e.toString());
		} catch (Exception e) {
			logger.debug("error:{}", e.toString());
		}
	}

	@After
	public void after() {
		sqlSession.commit();
	}

	@Test
	public void testCreate() {
		repository.create();
	}

	@Test
	public void testInsert() throws ParseException {
		String dateString = "2016-09-30";
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		Date date = sdf.parse(dateString);

		Map<String, Object> data = new HashMap<String, Object>();
		data.put("id", 1);
		data.put("name", "jack");
		data.put("time", date);

		repository.insert(data);
	}

	@Test
	public void testUpdate() throws ParseException {
		String dateString = "2016-09-30";
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		Date date = sdf.parse(dateString);

		Map<String, Object> data = new HashMap<String, Object>();
		data.put("id", 1);
		data.put("name", "jack");
		data.put("time", date);

		repository.update(data);
	}

	private SqlSession sqlSession;
	private Repository repository;

	private final Logger logger = LogManager.getLogger();
}
